@@ -1,18 +1,26 @@
 package Email::MIME::RFC2047;
-BEGIN {
-  $Email::MIME::RFC2047::VERSION = '0.91';
-}
-
+$Email::MIME::RFC2047::VERSION = '0.92';
 use strict;
+use warnings;
+
+# ABSTRACT: Correct handling of non-ASCII MIME headers
 
 1;
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Email::MIME::RFC2047 - Correct handling of non-ASCII MIME headers
 
+=head1 VERSION
+
+version 0.92
+
 =head1 SYNOPSIS
 
  use Email::MIME;
@@ -99,11 +107,9 @@ Nick Wellnhofer <wellnhofer@aevum.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) Nick Wellnhofer, 2009
+This software is copyright (c) 2015 by Nick Wellnhofer.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.0 or,
-at your option, any later version of Perl 5 you may have available.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
