@@ -1,9 +1,9 @@
 package Email::MIME::RFC2047::Decoder;
-BEGIN {
-  $Email::MIME::RFC2047::Decoder::VERSION = '0.91';
-}
-
+$Email::MIME::RFC2047::Decoder::VERSION = '0.92';
 use strict;
+use warnings;
+
+# ABSTRACT: Decoding of non-ASCII MIME headers
 
 use Encode ();
 use MIME::Base64 ();
@@ -27,7 +27,7 @@ my $encoded_word_text_re = qr/
             )+
         ) |
         [Qq] \?
-        ( [^?\x00-\x20\x7f-\x{ffff}]+ )
+        ( [^?\x00-\x20\x7f-\x{10ffff}]+ )
     )
     \? =
     (?= \z | \s )
@@ -47,7 +47,7 @@ my $encoded_word_phrase_re = qr/
             )+
         ) |
         [Qq] \?
-        ( [^?\x00-\x20$rfc_specials\x7f-\x{ffff}]+ )
+        ( [^?\x00-\x20$rfc_specials\x7f-\x{10ffff}]+ )
     )
     \? =
     (?= \z | [\s$rfc_specials_no_quote] )
@@ -188,10 +188,18 @@ sub _decode {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Email::MIME::RFC2047::Decoder - Decoding of non-ASCII MIME headers
 
+=head1 VERSION
+
+version 0.92
+
 =head1 SYNOPSIS
 
  use Email::MIME::RFC2047::Decoder;
@@ -225,7 +233,7 @@ Decodes any MIME header field for which the field body is defined as '*text'
 
 $encoded_text can also be a reference to a scalar. In this case the scalar
 is processed starting from the current search position. See L<perlfunc/pos>.
- 
+
 The resulting string is trimmed and any whitespace is collapsed.
 
 =head2 decode_phrase
@@ -247,11 +255,9 @@ Nick Wellnhofer <wellnhofer@aevum.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) Nick Wellnhofer, 2009
+This software is copyright (c) 2015 by Nick Wellnhofer.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.0 or,
-at your option, any later version of Perl 5 you may have available.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
