@@ -1,9 +1,9 @@
 package Email::MIME::RFC2047::Encoder;
-BEGIN {
-  $Email::MIME::RFC2047::Encoder::VERSION = '0.91';
-}
-
+$Email::MIME::RFC2047::Encoder::VERSION = '0.92';
 use strict;
+use warnings;
+
+# ABSTRACT: Encoding of non-ASCII MIME headers
 
 use Encode ();
 use MIME::Base64 ();
@@ -70,7 +70,7 @@ sub _encode {
 
         my $word_type;
 
-        if($word =~ /[\x80-\x{ffff}]|(^=\?.*\?=\z)/s) {
+        if($word =~ /[\x80-\x{10ffff}]|(^=\?.*\?=\z)/s) {
             # also encode any word that starts with '=?' and ends with '?='
             $word_type = 'mime';
         }
@@ -111,7 +111,7 @@ sub _encode {
                     # special character
                     $chunk = sprintf('=%02x', ord($char));
                 }
-                elsif($char =~ /[\x80-\x{ffff}]/) {
+                elsif($char =~ /[\x80-\x{10ffff}]/) {
                     # non-ASCII character
 
                     my $enc_char = $encoder->encode($char);
@@ -183,10 +183,18 @@ sub _finish_buffer {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Email::MIME::RFC2047::Encoder - Encoding of non-ASCII MIME headers
 
+=head1 VERSION
+
+version 0.92
+
 =head1 SYNOPSIS
 
  use Email::MIME::RFC2047::Encoder;
@@ -260,11 +268,9 @@ Nick Wellnhofer <wellnhofer@aevum.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) Nick Wellnhofer, 2009
+This software is copyright (c) 2015 by Nick Wellnhofer.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.0 or,
-at your option, any later version of Perl 5 you may have available.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
