@@ -1,9 +1,9 @@
 package Email::MIME::RFC2047::Parser;
-BEGIN {
-  $Email::MIME::RFC2047::Parser::VERSION = '0.91';
-}
-
+$Email::MIME::RFC2047::Parser::VERSION = '0.92';
 use strict;
+use warnings;
+
+# ABSTRACT: Base class for parsers
 
 sub _parse_error {
     my ($class, $string_ref, $what) = @_;
@@ -31,10 +31,18 @@ sub _parse_error {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Email::MIME::RFC2047::Parser - Base class for parsers
 
+=head1 VERSION
+
+version 0.92
+
 =head1 DESCRIPTION
 
 This is a base class for the packages parsing address headers.
@@ -45,11 +53,9 @@ Nick Wellnhofer <wellnhofer@aevum.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) Nick Wellnhofer, 2009
+This software is copyright (c) 2015 by Nick Wellnhofer.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.0 or,
-at your option, any later version of Perl 5 you may have available.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
